@@ -316,6 +316,19 @@ class Hint(Expression):
     arg_types = {"expressions": True}
 
 
+class Identifier(Expression):
+    arg_types = {"this": True, "quoted": False}
+
+    def __eq__(self, other):
+        return (
+            isinstance(other, Identifier)
+            and (self.this or "").upper() == (other.this or "").upper()
+        )
+
+    def __hash__(self):
+        return hash((self.key, self.this.upper()))
+
+
 class Insert(Expression):
     arg_types = {"this": True, "expression": True, "overwrite": False, "exists": False}
 
@@ -820,19 +833,6 @@ class Greatest(Func):
     is_var_len_args = True
 
 
-class Identifier(Func):
-    arg_types = {"this": True, "quoted": False}
-
-    def __eq__(self, other):
-        return (
-            isinstance(other, Identifier)
-            and (self.this or "").upper() == (other.this or "").upper()
-        )
-
-    def __hash__(self):
-        return hash((self.key, self.this.upper()))
-
-
 class If(Func):
     arg_types = {"this": True, "true": True, "false": False}
 
